summaryrefslogtreecommitdiffstats
path: root/src/H5Fint.c
diff options
context:
space:
mode:
authorDana Robinson <43805+derobins@users.noreply.github.com>2023-09-14 17:54:00 (GMT)
committerGitHub <noreply@github.com>2023-09-14 17:54:00 (GMT)
commitaa849f07e323e4654ac22dbcd2221d9c8d357486 (patch)
treef7a9f4ec99cbd92ea8d7fb2f57e1838cc71bdd7f /src/H5Fint.c
parentffa4bdac0a686aa00705b72132c5e8948cfee9db (diff)
downloadhdf5-aa849f07e323e4654ac22dbcd2221d9c8d357486.zip
hdf5-aa849f07e323e4654ac22dbcd2221d9c8d357486.tar.gz
hdf5-aa849f07e323e4654ac22dbcd2221d9c8d357486.tar.bz2
Remove HD prefix from math functions (#3538)
Diffstat (limited to 'src/H5Fint.c')
-rw-r--r--src/H5Fint.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/H5Fint.c b/src/H5Fint.c
index 607dbad..8029d35 100644
--- a/src/H5Fint.c
+++ b/src/H5Fint.c
@@ -3307,7 +3307,7 @@ H5F_track_metadata_read_retries(H5F_t *f, unsigned actype, unsigned retries)
HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
/* Index to retries based on log10 */
- tmp = HDlog10((double)retries);
+ tmp = log10((double)retries);
log_ind = (unsigned)tmp;
assert(log_ind < f->shared->retries_nbins);
@@ -3345,9 +3345,9 @@ H5F_set_retries(H5F_t *f)
/* Initialize the # of bins for retries */
f->shared->retries_nbins = 0;
if (f->shared->read_attempts > 1) {
/* Use HDceil to ensure that the log10 value is rounded up to the
nearest integer before casting to unsigned */
- tmp = HDceil(HDlog10((double)f->shared->read_attempts));
+ tmp = ceil(log10((double)f->shared->read_attempts));
f->shared->retries_nbins = (unsigned)tmp;
}
@@ -3345,9 +3345,9 @@ H5F_set_retries(H5F_t *f)
f->shared->retries_nbins = 0;
if (f->shared->read_attempts > 1) {
- /* Use HDceil to ensure that the log10 value is rounded up to the
+ /* Use ceil to ensure that the log10 value is rounded up to the
nearest integer before casting to unsigned */